package com.ruoyi.system.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.system.domain.ZsOperationWarnconfig;
import com.ruoyi.system.mapper.ZsOperationWarnconfigMapper;
import com.ruoyi.system.task.MonitorTaskScheduler;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.domain.bo.ZsOperationWarnresultBo;
import com.ruoyi.system.domain.vo.ZsOperationWarnresultVo;
import com.ruoyi.system.domain.ZsOperationWarnresult;
import com.ruoyi.system.mapper.ZsOperationWarnresultMapper;
import com.ruoyi.system.service.IZsOperationWarnresultService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 预警结果Service业务层处理
 *
 * @author 王强
 * @date 2025-05-12
 */
@RequiredArgsConstructor
@Service
public class ZsOperationWarnresultServiceImpl implements IZsOperationWarnresultService {

    private final ZsOperationWarnresultMapper baseMapper;
    @Autowired
    private MonitorTaskScheduler monitorTaskScheduler;
    @Autowired
    private ZsOperationWarnconfigMapper zsOperationWarnconfigMapper;
    /**
     * 查询预警结果
     */
    @Override
    public ZsOperationWarnresultVo queryById(Long id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询预警结果列表
     */
    @Override
    public TableDataInfo<ZsOperationWarnresultVo> queryPageList(ZsOperationWarnresultBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZsOperationWarnresult> lqw = buildQueryWrapper(bo);
        Page<ZsOperationWarnresultVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询预警结果列表
     */
    @Override
    public List<ZsOperationWarnresultVo> queryList(ZsOperationWarnresultBo bo) {
        LambdaQueryWrapper<ZsOperationWarnresult> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZsOperationWarnresult> buildQueryWrapper(ZsOperationWarnresultBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZsOperationWarnresult> lqw = Wrappers.lambdaQuery();
        lqw.between(params.get("beginWarnTime") != null && params.get("endWarnTime") != null,
            ZsOperationWarnresult::getWarnTime ,params.get("beginWarnTime"), params.get("endWarnTime"));
        lqw.like(StringUtils.isNotBlank(bo.getGoodsSkuName()), ZsOperationWarnresult::getGoodsSkuName, bo.getGoodsSkuName());
        lqw.eq(StringUtils.isNotBlank(bo.getGoodsSkuSn()), ZsOperationWarnresult::getGoodsSkuSn, bo.getGoodsSkuSn());
        lqw.eq(bo.getStatus() != null, ZsOperationWarnresult::getStatus, bo.getStatus());
        return lqw;
    }

    /**
     * 新增预警结果
     */
    @Override
    public Boolean insertByBo(ZsOperationWarnresultBo bo) {
        ZsOperationWarnresult add = BeanUtil.toBean(bo, ZsOperationWarnresult.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改预警结果
     */
    @Override
    public Boolean updateByBo(ZsOperationWarnresultBo bo) {
        ZsOperationWarnresult update = BeanUtil.toBean(bo, ZsOperationWarnresult.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZsOperationWarnresult entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除预警结果
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
    //拉取商品 进行比对
    @Override
    public void monitorWarn() {
        List<ZsOperationWarnconfig> zsOperationWarnconfigs =  zsOperationWarnconfigMapper.selectList();
        if (zsOperationWarnconfigs!=null&&zsOperationWarnconfigs.size()>0) {
            ZsOperationWarnconfig zsOperationWarnconfig = zsOperationWarnconfigs.get(0);
            monitorTaskScheduler.monitorWarn(zsOperationWarnconfig);
        }
    }
}
